#
# spec file for package python-reno
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# uses openstack packages: build and depend on default python3 provider only
%define pythons python3
Name:           python-reno
Version:        4.1.0
Release:        1.2
Summary:        RElease NOtes manager
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://www.openstack.org/
Source0:        https://files.pythonhosted.org/packages/source/r/reno/reno-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML >= 5.3.1}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module dulwich >= 0.15.0}
BuildRequires:  %{python_module openstackdocstheme >= 2.2.1}
BuildRequires:  %{python_module oslotest}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module stestr}
BuildRequires:  %{python_module testscenarios}
BuildRequires:  %{python_module testtools}
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  gpg2
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML >= 3.10
Requires:       python-Sphinx
Requires:       python-docutils
Requires:       python-dulwich >= 0.15.0
Requires:       python-pbr
Requires:       python-six
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Reno is a release notes manager for storing release notes in a git
repository and then building documentation from them.

%prep
%autosetup -n reno-%{version}

%build
%python_build

%install
%python_install
%python_expand rm -r %{buildroot}%{$python_sitelib}/reno/tests
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/reno

%post
%python_install_alternative reno

%postun
%python_uninstall_alternative reno

%check
rm -rf .git
git init .
%python_exec -m stestr.cli run

%files %{python_files}
%license LICENSE
%python_alternative %{_bindir}/reno
%{python_sitelib}/reno
%{python_sitelib}/*.egg-info

%changelog
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 4.1.0:
  * Respect EOM tag for branches in unmaintained status
  * Update supported python versions
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.0:
  * Order branches according to OpenStack release names
  * Fix scanner tests failing with modern Git
  * Remove python-dev from bindep
  * remove unicode from code
  * Don't attempt to pull from empty cache file
  * Update CI to use unversioned jobs template
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 3.5.0:
  * Close files opened by Scanner, Loader
  * loader: Validate section keys
  * loader: Improve tests and logging
  * loader: Handle note files missing top-level keys
  * Moving to OFTC
  * [community goal] Update contributor documentation
  * setup.cfg: Replace dashes with underscores
  * Handle repositories with a default branch other than master
  * Use py3 as the default runtime for tox
  * Deny creating subdirectories
  * drop lower-constraints
  * fix: order tags to be sure to favor release tag over pre-release tags
  * raise the minimum version of pyyaml
  * add \`semver-next\` command
  * add release note for \`encoding\` option
  * [trivial] Use opendev url for source code link
  * Add config option to set default character encoding
  * Some cleanups
  * Switch to newer openstackdocstheme version
* Mon Dec 14 2020 Benjamin Greiner <code@bnavigator.de>
- This package depends on packages from openstack, which are only
  available for the default python3 flavor. As a consequence,
  also only build for the primary python3-flavor.
  gh#openSUSE/python-rpm-macros#66
* Fri Jun  5 2020 Dirk Mueller <dmueller@suse.com>
- update 3.1.0
  * Set parallel\_read\_safe to True
  * Handle empty config files
  * Add cache support for release dates
  * Remove future imports
  * Keep scanning master branch after first shared commit
  * Sort config options
  * Add support for release dates
  * sphinxext: Support rootdir discovery without git
  * Use unittest.mock instead of third party mock
  * tox: Suppress output
  * do not include external svgs from readme in docs
  * Update hacking for Python3
* Wed Apr 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.0.1
  * scan the whole branch if a version cannot be found
* Fri Mar 27 2020 pgajdos@suse.com
- version update to 3.0.0
  * Remove usage of six
  * [ussuri][goal] Drop python 2.7 support and testing
  * Add extension metadata to sphinxext
  * Handle Windows compatibility
  * Scan all branches for cache generation
  * Avoid docutils 0.15 with py2
  * Add Python 3 Train unit tests
  * Fix py27 test: Update sphinx requirement
  * OpenDev Migration Patch
  * Switch to current hacking
  * Remove references to oslosphinx
* Thu Jun 13 2019 cloud-devel@suse.de
- update to version 2.11.3 (bsc#1137659)
  - Streamline published release notes
  - switch doc and pypi jobs to use python3
  - Migrate the link of bug report button to storyboard
  - update sphinx to at least 1.6.1
  - include the branch name in anchors to make them more unique
  - add lower-constraints tox environment and job
  - Update the min version of tox to 2.0
  - cleanups for dev workflow descriptions
  - Add python 3.6 unit test job
  - import zuul job settings from project-config
  - Collapse Unreleased and Mainline sections
  - add unreleased_version_title configuration option
  - trivial change to contributing instructions
  - refactor handling of missing config files for better testing
  - Change openstack-dev to openstack-discuss
  - update the oudated URL in doc
  - preserve the order of tags when reading the cache file
  - Enhance the travis hack
  - only override config values from command line if they are actually set
  - move sphinx flags to tox.ini
  - report line numbers for generated content more accurately
  - Update links in README
  - Switch to use stestr for unit test
  - update bug report URLs to use storyboard
  - sphinxext: Use 'sphinx.util.logging'
  - sphinxext: Use unicode_literals
  - Fix traceback when no args are passed to reno
  - tests: Use mock decorator instead of context manager
  - Integrate a setuptools command
  - build our docs with the lower-constraints
  - fix documentation project template
  - doc: Note development workflows supported by reno
  - build universal wheels
  - move package publishing template back to project-config
  - link to the europython 2018 presentation about reno
  - update test fixtures to capture log output
  - fix tox python3 overrides
  - Make section titles have stable anchor links
  - Add cover job
  - add python 3.7 unit test job
  - Allow tags prefixed with v in default regex
  - Update url in HACKING.rst
  - Use unicode for debug string
  - Add usage with travis CI to docs
  - report when loading data from the cache file
  - Update sphinx extension logging
* Mon Feb 26 2018 cloud-devel@suse.de
- update to version 2.7.0
  - improve output messages
  - add an internal sphinx extension to show the configuration defaults
  - support scanning closed stable branches
  - define options with help text
* Mon Dec  4 2017 cloud-devel@suse.de
- update to version 2.6.0
  - remove some duplication in ChangeTracker
  - Replace http with https
  - Add user details for editing stable branch notes
  - switch from oslosphinx to openstackdocstheme
  - Update documention link for doc migration
  - loader: Extract cache filename from config object
  - expand examples in documentation
  - ignore changes until the file is added within the scanned range
  - fix release note markup
  - Allow users to change prelude section name
  - Block comment should start with '# '
  - Clean up rendered HTML with openstackdocstheme
  - update bindep list
  - requirements: Stop requiring a specific pbr version
  - Move notesdir default to 'defaults' module
  - Remove Babel from setup.cfg and requirements
  - rearrange the existing docs to follow the new standard layout
  - Support repodir config files
  - add release note for scanner fix
  - Add option to create release note from user-provided template
  - update ref search logic for zuulv3 CI layout
  - release note for zuulv3 fix
  - allow release notes sections to be single strings
  - add option for ignoring some notes files
* Sat Aug  5 2017 cloud-devel@suse.de
- update to version 2.4.1
  - add function for reducing change list to operations
  - sphinxext: Include branch information in source name
  - Properly declare dependency on six
  - return the name of the cache file created
  - Have import order follow standard and fix misspelling
  - Remove discover from test-requirements
  - Replace LOG.wirn with LOG.warning
  - Support to set a custom template used to create new notes
  - set up logging in the sphinx extension
  - set relnotesdir to default inside config
  - Changed the link to home-page
  - Show team and repo badges on README
  - Using fixtures.MockPatch instead of mockpatch.Patch
  - clarify automatic inclusion of prelude section
  - update release notes
  - let the Config object give us the path to the notes
  - define Config class
  - logging improvements
  - trim Newton history to avoid duplication
  - use dulwich to find the current version on a branch
  - fix a problem scanning for the base of a branch with no tag
  - Wrap template at ~79 characters
  - add filename and sha in comments in report output
  - Add YAML configuration parsing
  - Document how reno handles eol branches in config
  - add a --title option to the report command
  - doc: Document the available configuration options
  - Remove oslotest from test-requirements.txt
  - add a lint command
  - make sections configurable
  - add sha info to ChangeTracker debug output
  - move tag management into repo subclass
  - do not test python 3.4 by default
  - Remove link to modindex
  - tone down the warning for missing configuration file
  - deal with unsigned tags
  - fix the way we handle deleted notes
  - fix the logic for determining where to stop scanning a branch
  - use unicode literals in scanner tests
  - do not allow multiple files with the same UID
  - Add support for tags tagging other tags
  - Enable to create and edit a note with reno new
  - allow tracking branch names when the branches only exist on origin
  - only show recent releases on the current series pages
  - deal with remote branches
  - refactor change tracking in scanner
  - use dulwich to get the contents of a file
  - Make note template follow correct formatting
  - add the irc channel to the readme file
  - support removed stable branches
  - add reference to project team guide for openstack projects
  - use dulwich to implement get_notes_by_version
  - Add debugging section to docs
  - reconfigure release notes display to include newton
  - Link to reStructuredText primer from usage docs
  - quiet gpg commands in tests
  - ensure tags are returned in a consistent order
  - let the Config class clean up the reporoot we're given
  - traversal performance improvements
  - fix sphinxext scanner when it has a list of versions to include
  - optimize check for the current version
  - add more tests for _get_ref
  - log scanner tests in a way that makes them easier to debug
  - Make oslosphinx requirement optional
  - skip the test that fails on git 2.9.2
  - fix an infinite loop in the topo traversal algorithm
  - documentation improvements
  - use dulwich to determine the tags on a branch
  - add a null logging handler
  - show full history
  - fix bytes/str handling when looking for file content
  - use Config instead of individual args with parameters
  - Add support for custom tag version schemes
  - add release note for log level fix
  - add python 3.5 classifier and default tox env
  - Remove support for py34
  - Remove support for py33
  - set the default for reporoot for the command line
  - add missing reporoot arg to 'new' command
  - stop scanning at the base of a branch
  - comment out openstack governance badges
  - teach the scanner to look at uncommitted files
  - use dulwich to determine the branch base
  - shortcut the branch scan by looking at the version number
  - try to discover the repository root in sphinx builds
  - deal with non-unique UIDs
  - log git commands run in scanner tests
  - fix branch handling in sphinx extension
  - ignore staged files that are not notes
  - uncap pbr dependency
  - add configuration option to not stop at branch base
  - add --no-show-source option to report command
  - Clean imports in code
  - use dulwich's tree traversal to look up repo contents
  - create GitRepoFixture
  - fix the logic for deciding what to show as the "current" series
  - do not use sphinx 1.6.1
  - add tests for determining the branch base
  - modify the change aggregation api
  - fix reference to config.yaml
  - centralize handling of branches without base tags
  - fix some minor formatting issues with release notes
  - lower the log level for an error message
  - ignore null-merges
  - do not assume the current branch is the most recent
  - Fix RST
  - remove cruft from readme
  - refactor existing implementation into a class
  - Update to Sphinx 1.5, tread warnings as errors
  - fix logic for deciding when to stop scanning a branch
- add _service and switch to upstream rpm-packaging spec
* Thu Aug 25 2016 tbechtold@suse.com
- Use pypi.io as Source url
* Thu Aug 25 2016 tbechtold@suse.com
- update to 1.8.0:
  * ignore all coverage output files
  * add warnings for malformated input
  * add API for writing the cache file
  * report extra files with warnings
  * Ignore empty sections in notes
  * Clean up oslo-incubator stuff
  * [Trivial] Remove executable privilege of doc/source/conf.py
* Sat Jun  4 2016 tbechtold@suse.com
- update to 1.6.2:
  * default to collapsing pre-releases in sphinxext
  * handle deleted notes properly
  * refactor argument buildup to make it more reusable
  * improve test coverage
  * always show coverage report for test runs
  * Add deprecations section to usage documentation
  * use less entropy in unit tests
  * collapse pre-release notes into regular releases by default
* Mon Feb 15 2016 dmueller@suse.com
- Initial package (1.5.0)
